/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2013 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.fingerprint;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.nio.file.Path;
import it.tidalwave.actor.MessageSupport;
import it.tidalwave.actor.annotation.Message;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import static lombok.AccessLevel.*;
import lombok.experimental.Wither;

/***********************************************************************************************************************
 * 
 * @stereotype Message
 * 
 * A message which notifies that a fingerprint for a file has been computed.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Message @Immutable 
@RequiredArgsConstructor(access=PRIVATE) @EqualsAndHashCode(callSuper=false) @ToString(callSuper=false)
public class FingerprintComputedMessage extends MessageSupport
  {
    @Nonnull @Getter
    private final Path path;
    
    @Nonnull @Wither @Getter
    private final Fingerprint fingerprint;
    
    @Nonnull
    public static FingerprintComputedMessage forPath (final @Nonnull Path path)
      {
        return new FingerprintComputedMessage(path, new Fingerprint("", ""));  
      }
  }
